# Generated by roxygen2: do not edit by hand

export(buildSeuratMarkerList)
export(factorialPrimePowers)
export(mtCorrectDF)
export(mtCorrectV)
export(probCounts2MN)
export(probCounts3N)
export(pvalCounts2MN)
export(pvalCounts3N)
export(pvalObjects)
export(pvalSets2MN)
export(pvalSets2N)
export(pvalSets3N)
export(runLISTO)
export(vChoose)
export(vSum)
importFrom(methods,is)
importFrom(parallel,clusterExport)
importFrom(parallel,makeCluster)
importFrom(parallel,parSapply)
importFrom(parallel,stopCluster)
importFrom(primes,generate_n_primes)
importFrom(primes,generate_primes)
importFrom(statisfactory,psum)
importFrom(stats,dhyper)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,phyper)
