donorPath <- system.file('extdata', 'donorMarkers.qs2', package='LISTO')
donorMarkers <- qs2::qs_read(donorPath)
labelPath <- system.file('extdata', 'labelMarkers.qs2', package='LISTO')
labelMarkers <- qs2::qs_read(labelPath)
sigPath <- system.file('extdata', 'signatures.qs2', package='LISTO')
signatures <- qs2::qs_read(sigPath)
universe1Path <- system.file('extdata', 'universe1.qs2', package='LISTO')
universe1 <- qs2::qs_read(universe1Path)
universe2Path <- system.file('extdata', 'universe2.qs2', package='LISTO')
universe2 <- qs2::qs_read(universe1Path)
seuratPath <- system.file('extdata', 'seuratObj.qs2', package='LISTO')
seuratObj <- qs2::qs_read(seuratPath)
